summaryrefslogtreecommitdiffstats
path: root/import/chips/p9/utils/p9_putRingUtils.C
diff options
context:
space:
mode:
Diffstat (limited to 'import/chips/p9/utils/p9_putRingUtils.C')
-rw-r--r--import/chips/p9/utils/p9_putRingUtils.C6
1 files changed, 3 insertions, 3 deletions
diff --git a/import/chips/p9/utils/p9_putRingUtils.C b/import/chips/p9/utils/p9_putRingUtils.C
index 5dbb9816..bc2440af 100644
--- a/import/chips/p9/utils/p9_putRingUtils.C
+++ b/import/chips/p9/utils/p9_putRingUtils.C
@@ -294,8 +294,8 @@ fapi2::ReturnCode standardScan(
// Add the chiplet ID in the Scom Address
l_scomAddress |= l_chiplet;
- // @TODO: Value 200 is a random number to start with.
- uint8_t l_attempts = 200;
+ // @TODO: Value 300 is a random number to start with.
+ uint32_t l_attempts = 300;
while(l_attempts > 0)
{
@@ -322,7 +322,7 @@ fapi2::ReturnCode standardScan(
// @TODO: 1 micro second is a number that works now.
// Need to derive the real delay number.
- fapi2::delay(1000, 0);
+ fapi2::delay(1000, 1000000);
}
OpenPOWER on IntegriCloud